@@ -2,7 +2,7 @@
 package CPAN::Mirrored::By;
 use strict;
 use vars qw($VERSION);
-$VERSION = sprintf "%.6f", substr(q$Rev: 819 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 825 $,4)/1000000 + 5.4;
 
 sub new { 
     my($self,@arg) = @_;
@@ -21,7 +21,7 @@ use File::Basename ();
 use File::Path ();
 use File::Spec;
 use vars qw($VERSION $urllist);
-$VERSION = sprintf "%.6f", substr(q$Rev: 819 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 825 $,4)/1000000 + 5.4;
 
 =head1 NAME
 
@@ -80,7 +80,7 @@ sub init {
 
     my $manual_conf;
 
-    local *_real_prompt = \&CPAN::Shell::colorable_makemaker_prompt;
+    local *_real_prompt;
     if ( $args{autoconfig} ) {
         $manual_conf = "no";
     } elsif ($matcher) {
@@ -847,6 +847,9 @@ sub _strip_spaces {
 }
 
 sub prompt ($;$) {
+    unless (defined &_real_prompt) {
+        *_real_prompt = \&CPAN::Shell::colorable_makemaker_prompt;
+    }
     my $ans = _real_prompt(@_);
 
     _strip_spaces($ans);
